#
# spec file for package perl-XML-DOM
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-XML-DOM
Version:        1.46
Release:        1.11
%define cpan_name XML-DOM
Summary:        Perl Module for Building Dom Level 1 Compliant Document Structures
# "You can redistribute it and/or modify it under the same terms as Perl itself"
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
URL:            https://metacpan.org/pod/XML::DOM
Source0:        https://cpan.metacpan.org/authors/id/T/TJ/TJMATHER/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(LWP::UserAgent)
BuildRequires:  perl(XML::Parser) >= 2.30
BuildRequires:  perl(XML::Parser::PerlSAX) >= 0.07
BuildRequires:  perl(XML::RegExp)
Requires:       perl(LWP::UserAgent)
Requires:       perl(XML::Parser) >= 2.30
Requires:       perl(XML::Parser::PerlSAX) >= 0.07
Requires:       perl(XML::RegExp)
%{perl_requires}

%description
This module extends the XML::Parser module by Clark Cooper. The XML::Parser
module is built on top of XML::Parser::Expat, which is a lower level
interface to James Clark's expat library.

XML::DOM::Parser is derived from XML::Parser. It parses XML strings or
files and builds a data structure that conforms to the API of the Document
Object Model as described at http://www.w3.org/TR/REC-DOM-Level-1. See the
XML::Parser manpage for other available features of the XML::DOM::Parser
class. Note that the 'Style' property should not be used (it is set
internally.)

The XML::Parser _NoExpand_ option is more or less supported, in that it
will generate EntityReference objects whenever an entity reference is
encountered in character data. I'm not sure how useful this is. Any
comments are welcome.

As described in the synopsis, when you create an XML::DOM::Parser object,
the parse and parsefile methods create an _XML::DOM::Document_ object from
the specified input. This Document object can then be examined, modified
and written back out to a file or converted to a string.

When using XML::DOM with XML::Parser version 2.19 and up, setting the
XML::DOM::Parser option _KeepCDATA_ to 1 will store CDATASections in
CDATASection nodes, instead of converting them to Text nodes. Subsequent
CDATASection nodes will be merged into one. Let me know if this is a
problem.

When using XML::Parser 2.27 and above, you can suppress expansion of
parameter entity references (e.g. %pent;) in the DTD, by setting
_ParseParamEnt_ to 1 and _ExpandParamEnt_ to 0. See Hidden Nodes for
details.

A Document has a tree structure consisting of _Node_ objects. A Node may
contain other nodes, depending on its type. A Document may have Element,
Text, Comment, and CDATASection nodes. Element nodes may have Attr,
Element, Text, Comment, and CDATASection nodes. The other nodes may not
have any child nodes.

This module adds several node types that are not part of the DOM spec
(yet.) These are: ElementDecl (for <!ELEMENT ...> declarations),
AttlistDecl (for <!ATTLIST ...> declarations), XMLDecl (for <?xml ...?>
declarations) and AttDef (for attribute definitions in an AttlistDecl.)

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc BUGS Changes FAQ.xml README samples XML-Parser-2.31.patch

%changelog
* Mon May 23 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Fix license tag, remove CHECK(...) and use correct
  "you can redistribute it and/or modify it under the same terms as
  Perl itself." aka GPL-1.0+ OR Artistic-1.0
- Use https for URL and SourceURL
* Thu Sep 22 2016 coolo@suse.com
- updated to 1.46
  see /usr/share/doc/packages/perl-XML-DOM/Changes
  1.46 (tjmather) 09/21/2016
  - Correct name passed to WriteMakefile to XML::DOM (was XML/Dom)
* Fri Aug 21 2015 cfarrell@suse.com
- license update: Artistic-1.0 or GPL-1.0+
  CHECK(...) not valid
* Wed Aug 19 2015 coolo@suse.com
- updated to 1.45
  see /usr/share/doc/packages/perl-XML-DOM/Changes
  1.45 (tjmather) 08/16/2015
  - Fix pod errors and a typo ( Florian Schlichting )
  - properly encode output for printToFile ( Martin Ferrari, Gregor Herrmann )
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Tue Jul 27 2010 chris@computersalat.de
- recreated by cpanspec 1.78
  o fix deps
- noarch
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Thu Jan 15 2009 anicka@suse.cz
- do not ignore test results (bnc#465994)
* Thu Feb  9 2006 anicka@suse.cz
- require perl-libwww-perl (#149416)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Aug  1 2005 mjancar@suse.cz
- update to 1.44
* Tue Mar  1 2005 mjancar@suse.cz
- require perl-XML-RegExp
* Mon Aug 16 2004 ro@suse.de
- ignore testsuite output for the moment
  to build dependant packages
* Thu Feb 26 2004 mjancar@suse.cz
- update to 1.43
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Jul 18 2003 poeml@suse.de
- use install_vendor and new %%perl_process_packlist macro
* Mon Jun 16 2003 mjancar@suse.cz
- fix filelist
* Mon May 19 2003 ro@suse.de
- remove perllocal.pod
* Fri Dec 27 2002 prehak@suse.cz
- updated to version 1.42
- reenabled make test except fot one test
* Wed Jul 31 2002 mls@suse.de
- disable 'make test' for now as unicode stuff seems to be
  incompatible with perl-5.8.0. Waiting for new release...
* Tue Jul 23 2002 prehak@suse.cz
- update to version 1.39
- enabled make test
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Tue Jan 15 2002 rvasice@suse.cz
- update to version 1.36
* Thu Aug 16 2001 rvasice@suse.cz
- update to 1.31
* Fri Nov 10 2000 cihlar@suse.cz
- renamed p_xmldom -> perl-XML-DOM
- bzipped sources
- fixed file list
* Mon Aug 21 2000 ro@suse.de
- adapted for perl-5.6
* Thu Apr 20 2000 cihlar@suse.cz
- added BuildRoot
* Fri Jan 21 2000 ro@suse.de
- fixed filelist: use macro for mandir
* Tue Jan 18 2000 ke@suse.de
- Fix %%files list.
* Mon Jan 10 2000 ke@suse.de
- Update: version 1.25.
- Use %%{version} instead %%{ver} (predefined).
* Mon Jan 10 2000 ke@suse.de
- Add missing DOM.pm to the %%files list (#1630).
- Use version macro.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Aug  4 1999 ke@suse.de
- New package: version 1.23.
